darkhistory.spec.transferfunclist.TransferFuncInterp — DarkHistory documentation

# darkhistory.spec.transferfunclist.TransferFuncInterp

class `darkhistory.spec.transferfunclist.` `TransferFuncInterp`(tflistarrs, rs_nodes=None, log_interp=False)

  Interpolation function over list of TransferFuncList objects.

  Parameters: | tflist_arr : list of TransferFuncList TransferFuncList objects to interpolate over. Should be indexed by xH, (redshift regime) or (redshift regime, xH, xHe) x_arr : None or ndarray Array of xH or (xH, xHe) values corresponding to tflist_arr. rs_nodes : ndarray List of redshifts to transition between redshift regimes. log_interp : bool, optional If True, performs an interpolation over log of the grid values.
  Attributes: | rs : list of ndarray Redshift abscissa of the transfer functions. in_eng : list of ndarray Injection energy abscissa of the transfer functions. eng : list of ndarray Energy abscissa of the spectrum. dlnz : list of float The d ln(1+z) step for the transfer functions. spec_type : tuple of {‘N’, ‘dNdE’} The type of spectra stored in the transfer functions. rs_nodes : ndarray List of redshifts to transition between redshift regimes. grid_vals : tuple of ndarray The grid values in each redshift regime. x : tuple of ndarray Array of xH or (xH, xHe) in each redshift regime. interp_func : function An interpolation function over xH (optionally xHe) and rs.

  Methods

  get_tf |

  `__init__`(tflistarrs, rs_nodes=None, log_interp=False)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(tflistarrs[, rs_nodes, log_interp]) | Initialize self.
  `get_tf`(xH, xHe, rs) |

#### Previous topic

darkhistory.spec.transferfunclist

#### Next topic

darkhistory.spec.transferfunclist.TransferFuncInterps

### This Page

Show Source